/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.person.apio.internal.permission;

import com.liferay.apio.architect.credentials.Credentials;
import com.liferay.portal.apio.permission.HasPermission;
import com.liferay.portal.kernel.security.permission.ActionKeys;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portal.kernel.service.permission.PortalPermissionUtil;
import com.liferay.portal.kernel.service.permission.UserPermission;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alejandro Hernández
 */
@Component(property = "model.class.name=com.liferay.portal.kernel.model.User")
public class UserHasPermissionImpl implements HasPermission<Long> {

	@Override
	public Boolean forAdding(Credentials credentials) {
		return PortalPermissionUtil.contains(
			(PermissionChecker)credentials.get(), ActionKeys.ADD_USER);
	}

	@Override
	public Boolean forDeleting(Credentials credentials, Long userId) {
		return _userPermission.contains(
			(PermissionChecker)credentials.get(), userId, ActionKeys.DELETE);
	}

	@Override
	public Boolean forUpdating(Credentials credentials, Long userId) {
		return _userPermission.contains(
			(PermissionChecker)credentials.get(), userId, ActionKeys.UPDATE);
	}

	@Reference
	private UserPermission _userPermission;

}